@@ -83,20 +83,20 @@ class CliApplication():
             self.loginModal()
 
     def loginModal(self):
-        print("1. Admin")
-        print("2. User")
-        self.login_type = int(input("Login as: "))
+        # print("1. Admin")
+        # print("2. User")
+        # self.login_type = int(input("Login as: "))
 
-        while self.login_type < 1 or self.login_type > 2:
-            print("Please select an option number from the list above!")
-            self.login_type = int(input("Login as: "))
-        if self.login_type == 2:
-            self.org = input("Organization Account Id: ")
-            if not self.checkOrg(self.org):
-                print("Please check your organization account id and try again!")
-                sys.exit()
-        else:
-            self.org = 0
+        # while self.login_type < 1 or self.login_type > 2:
+        #     print("Please select an option number from the list above!")
+        #     self.login_type = int(input("Login as: "))
+        # if self.login_type == 2:
+        self.org = input("Organization Account Id: ")
+        if not self.checkOrg(self.org):
+            print("Please check your organization account id and try again!")
+            sys.exit()
+        # else:
+        #     self.org = 0
 
         self.email = input("Email: ")
         if not self.checkEmail(self.email):
@@ -268,12 +268,12 @@ class CliApplication():
             # print("Here: ", self.org, self.email, self.pwd)
 
             if not hasattr(self, "token"):
-                if not hasattr(self, "org"):
-                    validatedUser = self.validateUser(
-                        0, self.email, self.pwd)
-                else:
-                    validatedUser = self.validateUser(
-                        self.org or 0, self.email, self.pwd)
+                # if not hasattr(self, "org"):
+                #     validatedUser = self.validateUser(
+                #         0, self.email, self.pwd)
+                # else:
+                validatedUser = self.validateUser(
+                    self.org or 0, self.email, self.pwd)
 
             if not validatedUser:
                 print("User validation failed!")
